@@ -60,8 +60,18 @@ sub end : ActionClass('RenderView') {
             } (map { split m/\n/ } @{$c->error});
             $c->response->body(join("\n", @folded_errors));
             $c->clear_errors;
+        } elsif ($c->error->[0]
+                       ->isa("App::CamelPKI::Error::Privilege")) {
+        	$c->stash->{message} = "Insufficient privilege to execute this operation. Please contact the administrator if you think you should.";
+        	$c->stash->{template} = 'message.tt2';                     	
+        } else {
+        	#Not known errors
+        	$c->stash->{error} = $c->error->[0];
+        	$c->stash->{template} = 'error.tt2';
         }
+        $c->clear_errors;
     }
+    
 }
 
 =back
